# Based on https://gist.github.com/Mathieu-Castets/e36488c518d1fc4a03fa (thank you!)
nationalities = {
    'AD': ('andorran', 'andorrane'),
    'AE': ('émirien', 'émirienne'),
    'AF': ('afghan', 'afghane'),
    'AG': ('antiguayen', 'antiguayenne'),
    'AI': ('anguillais', 'anguillaise'),
    'AL': ('albanais', 'albanaise'),
    'AM': ('arménien', 'arménienne'),
    'AO': ('angolais', 'angolaise'),
    'AR': ('argentin', 'argentine'),
    'AS': ('samoan', 'samoane'),
    'AT': ('autrichien', 'autrichienne'),
    'AU': ('australien', 'australienne'),
    'AW': ('arubain', 'arubaine'),
    'AX': ('ålandais', 'ålandaise'),
    'AZ': ('azerbaïdjanais', 'azerbaïdjanaise'),
    'BA': ('bosnien', 'bosnienne'),
    'BB': ('barbadien', 'barbadienne'),
    'BD': ('bangladais', 'bangladaise'),
    'BE': ('belge', 'belge'),
    'BF': ('burkinabè', 'burkinabè'),
    'BG': ('bulgare', 'bulgare'),
    'BH': ('bahreïnien', 'bahreïnienne'),
    'BI': ('burundais', 'burundaise'),
    'BJ': ('béninois', 'béninoise'),
    'BM': ('bermudien', 'bermudienne'),
    'BN': ('brunéiens', 'brunéiennes'),
    'BO': ('bolivien', 'bolivienne'),
    'BR': ('brésilien', 'brésilienne'),
    'BS': ('bahamien', 'bahamienne'),
    'BT': ('bhoutanais', 'bhoutanaise'),
    'BW': ('botswanais', 'botswanaise'),
    'BY': ('biélorusse', 'biélorusse'),
    'BZ': ('bélizien', 'bélizienne'),
    'CA': ('canadien', 'canadienne'),
    'CD': ('congolais', 'congolaise'),
    'CF': ('centrafricain', 'centrafricaine'),
    'CG': ('congolais', 'congolaise'),
    'CH': ('suisse', 'suissesse'),
    'CI': ('ivoirien', 'ivoirienne'),
    'CK': ('cookien', 'cookienne'),
    'CL': ('chilien', 'chilienne'),
    'CM': ('camerounais', 'camerounaise'),
    'CN': ('chinois', 'chinoise'),
    'CO': ('colombien', 'colombienne'),
    'CR': ('costaricien', 'costaricienne'),
    'CU': ('cubain', 'cubaine'),
    'CV': ('cap-verdien', 'cap-verdienne'),
    'CY': ('chypriote', 'chypriote'),
    'CS': ('tchécoslovaque', 'tchécoslovaque'),
    'CZ': ('tchèque', 'tchèque'),
    'DE': ('allemand', 'allemande'),
    'DJ': ('djiboutien', 'djiboutienne'),
    'DK': ('danois', 'danoise'),
    'DM': ('dominiquais', 'dominiquaise'),
    'DO': ('dominicain', 'dominicaine'),
    'DZ': ('algérien', 'algérienne'),
    'EC': ('équatorien', 'équatorienne'),
    'EE': ('estonien', 'estonienne'),
    'EG': ('égyptien', 'égyptienne'),
    'EH': ('sahraoui', 'sahraouie'),
    'EL': ('grec', 'grecque'),
    'ER': ('érythréen', 'érythréenne'),
    'ES': ('espagnol', 'espagnole'),
    'ET': ('éthiopien', 'éthiopienne'),
    'FI': ('finlandais', 'finlandaise'),
    'FJ': ('fidjien', 'fidjienne'),
    'FK': ('malouin', 'malouine'),
    'FM': ('micronésien', 'micronésienne'),
    'FO': ('féroïen', 'féroïenne'),
    'FR': ('français', 'française'),
    'GA': ('gabonais', 'gabonaise'),
    'GB': ('britannique', 'britannique'),
    'GD': ('grenadin', 'grenadine'),
    'GE': ('géorgien', 'géorgienne'),
    'GH': ('ghanéen', 'ghanéenne'),
    'GI': ('gibraltarien', 'gibraltarienne'),
    'GL': ('groenlandais', 'groenlandaise'),
    'GM': ('gambien', 'gambienne'),
    'GN': ('guinéen', 'guinéenne'),
    'GQ': ('équatoguinéen', 'équatoguinéenne'),
    'GR': ('grec', 'grecque'),
    'GT': ('guatémaltèque', 'guatémaltèque'),
    'GU': ('guamien', 'guamienne'),
    'GW': ('bissaoguinéen', 'bissaoguinéenne'),
    'GY': ('guyanien', 'guyanienne'),
    'HK': ('hongkongais', 'hongkongaise'),
    'HN': ('hondurien', 'hondurienne'),
    'HR': ('croate', 'croate'),
    'HT': ('haïtien', 'haïtienne'),
    'HU': ('hongrois', 'hongroise'),
    'ID': ('indonésien', 'indonésienne'),
    'IE': ('irlandais', 'iirlandaise'),
    'IL': ('israélien', 'israélienne'),
    'IN': ('indien', 'indienne'),
    'IQ': ('iraquien', 'iraquienne'),
    'IR': ('iranien', 'iranienne'),
    'IS': ('islandais', 'islandaise'),
    'IT': ('italien', 'italienne'),
    'JM': ('jamaïcain', 'jamaïcaine'),
    'JO': ('jordanien', 'jordanienne'),
    'JP': ('japonais', 'japonaise'),
    'KE': ('kényan', 'kényane'),
    'KG': ('kirghize', 'kirghize'),
    'KH': ('cambodgien', 'cambodgienne'),
    'KI': ('kiribatien', 'kiribatienne'),
    'KM': ('comorien', 'comorienne'),
    'KN': ('christophien', 'christophienne'),
    'KP': ('nord-coréen', 'nord-coréenne'),
    'KR': ('sud-coréen', 'sud-coréenne'),
    'KW': ('koweïtien', 'koweïtienne'),
    'KY': ('caïmanais', 'caïmanaise'),
    'KZ': ('kazakh', 'kazakhe'),
    'LA': ('laotien', 'laotienne'),
    'LB': ('libanais', 'libanaise'),
    'LC': ('saint-lucien', 'saint-lucienne'),
    'LI': ('liechtensteinois', 'liechtensteinoise'),
    'LK': ('sri-lankais', 'sri-lankaise'),
    'LR': ('libérien', 'libérienne'),
    'LS': ('mosotho', 'mosotho'),
    'LT': ('lituanien', 'lituanienne'),
    'LU': ('luxembourgeois', 'luxembourgeoise'),
    'LV': ('letton', 'lettone'),
    'LY': ('libyen', 'libyenne'),
    'MA': ('marocain', 'marocaine'),
    'MC': ('monégasque', 'monégasque'),
    'MD': ('moldave', 'moldave'),
    'ME': ('monténégrin', 'monténégrine'),
    'MG': ('malgache', 'malgache'),
    'MH': ('marshallais', 'marshallaise'),
    'MK': ('macédonien', 'macédonienne'),
    'ML': ('malien', 'malienne'),
    'MM': ('birman', 'birmane'),
    'MN': ('mongol', 'mongole'),
    'MO': ('macanais', 'macanaise'),
    'MP': ('mariannais', 'mariannaise'),
    'MR': ('mauritanien', 'mauritanienne'),
    'MS': ('montserratien', 'montserratienne'),
    'MT': ('maltais', 'maltaise'),
    'MU': ('mauricien', 'mauricienne'),
    'MV': ('maldivien', 'maldivienne'),
    'MW': ('malawien', 'malawienne'),
    'MX': ('mexicain', 'mexicaine'),
    'MY': ('malaisien', 'malaisienne'),
    'MZ': ('mozambicain', 'mozambicaine'),
    'NA': ('namibien', 'namibienne'),
    'NE': ('nigérien', 'nigérienne'),
    'NG': ('nigérian', 'nigériane'),
    'NI': ('nicaraguayen', 'nicaraguayenne'),
    'NL': ('néerlandais', 'néerlandaise'),
    'NO': ('norvégien', 'norvégienne'),
    'NP': ('népalais', 'népalaise'),
    'NR': ('nauruan', 'nauruane'),
    'NU': ('niuéan', 'niuéane'),
    'NZ': ('néo-zélandais', 'néo-zélandaise'),
    'OM': ('omanais', 'omanaise'),
    'PA': ('panaméen', 'panaméenne'),
    'PE': ('péruvien', 'péruvienne'),
    'PG': ('papouasien', 'papouasienne'),
    'PH': ('philippin', 'philippine'),
    'PK': ('pakistanais', 'pakistanaise'),
    'PL': ('polonais', 'polonaise'),
    'PR': ('portoricain', 'portoricaine'),
    'PS': ('palestinien', 'palestinienne'),
    'PT': ('portugais', 'portugaise'),
    'PW': ('palaois', 'palaoise'),
    'PY': ('paraguayen', 'paraguayenne'),
    'QA': ('qatarien', 'qatarienne'),
    'RO': ('roumain', 'roumaine'),
    'RS': ('serbe', 'serbe'),
    'RU': ('russe', 'russe'),
    'RW': ('rwandais', 'rwandaise'),
    'SA': ('saoudien', 'saoudienne'),
    'SB': ('salomonais', 'salomonaise'),
    'SC': ('seychellois', 'seychelloise'),
    'SD': ('soudanais', 'soudanaise'),
    'SE': ('suédois', 'suédoise'),
    'SG': ('singapourien', 'singapourienne'),
    'SI': ('slovène', 'slovène'),
    'SK': ('slovaque', 'slovaque'),
    'SL': ('sierraléonais', 'sierraléonaise'),
    'SM': ('saint-marinais', 'saint-marinaise'),
    'SN': ('sénégalais', 'sénégalaise'),
    'SO': ('somalien', 'somalienne'),
    'SR': ('surinamais', 'surinamaise'),
    'SS': ('sud-soudanais', 'sud-soudanaise'),
    'ST': ('santoméen', 'santoméenne'),
    'SU': ('soviétique', 'soviétique'),
    'SV': ('salvadorien', 'salvadorienne'),
    'SY': ('syrien', 'syrienne'),
    'SZ': ('swazi', 'swazie'),
    'TC': ('émirats arabes unis', 'émirats arabes unis'),
    'TD': ('tchadien', 'tchadienne'),
    'TG': ('togolais', 'togolaise'),
    'TH': ('thaïlandais', 'thaïlandaise'),
    'TJ': ('tadjik', 'tadjike'),
    'TK': ('tokélaouen', 'tokélaouenne'),
    'TL': ('timorais', 'timoraise'),
    'TM': ('turkmène', 'turkmène'),
    'TN': ('tunisien', 'tunisienne'),
    'TO': ('tongan', 'tongane'),
    'TP': ('est-timorais', 'est-timoraise'),
    'TR': ('turc', 'turque'),
    'TT': ('trinidadien', 'trinidadienne'),
    'TV': ('tuvaluan', 'tuvaluane'),
    'TW': ('taïwanais', 'taïwanaise'),
    'TZ': ('tanzanien', 'tanzanienne'),
    'UA': ('ukrainien', 'ukrainienne'),
    'UG': ('ougandais', 'ougandaise'),
    'UK': ('britannique', 'britannique'),
    'US': ('américain', 'américaine'),
    'UY': ('uruguayen', 'uruguayenne'),
    'UZ': ('ouzbek', 'ouzbèke'),
    'VC': ('vincentais', 'vincentaise'),
    'VE': ('vénézuélien', 'vénézuélienne'),
    'VG': ('insulaires des îles vierges britanniques', 'insulaires des îles vierges britanniques'),
    'VI': ('insulaires des îles vierges', 'insulaires des îles vierges'),
    'VN': ('vietnamien', 'vietnamienne'),
    'VU': ('vanuatuan', 'vanuatuane'),
    'WS': ('samoan', 'samoane'),
    'XK': ('kosovar', 'kosovare'),
    'YE': ('yéménite', 'yéménite'),
    'YU': ('serbe', 'serbe'),
    'ZA': ('sud-africain', 'sud-africaine'),
    'ZM': ('zambien', 'zambienne'),
    'ZW': ('zimbabwéen', 'zimbabwéenne'),
}

countries = {
    'Andorre': 'AD',
    'Émirats arabes unis': 'AE',
    'Afghanistan': 'AF',
    'Antigua et Barbuda': 'AG',
    'Anguilla': 'AI',
    'Albanie': 'AL',
    'Curaçao': 'AN',
    'Angola': 'AO',
    'Argentine': 'AR',
    'Samoa américaines': 'AS',
    'Autriche': 'AT',
    'Australie': 'AU',
    'Aruba': 'AW',
    'Azerbaïdjan': 'AZ',
    'Bosnie-Herzégovine': 'BA',
    'Barbade': 'BB',
    'Bangladesh': 'BD',
    'Belgique': 'BE',
    'Burkina Faso': 'BF',
    'Bulgarie': 'BG',
    'Bahreïn': 'BH',
    'Burundi': 'BI',
    'Benin': 'BJ',
    'Bermudes': 'BM',
    'Brunei': 'BN',
    'Bolivie': 'BO',
    'Brésil': 'BR',
    'Bahamas': 'BS',
    'Bhoutan': 'BT',
    'Botswana': 'BW',
    'Biélorussie': 'BY',
    'Belize': 'BZ',
    'Canada': 'CA',
    'Congo RDC': 'CD',
    'République Centrafricaine': 'CF',
    'Congo (Brazzaville)': 'CG',
    'Suisse': 'CH',
    'Côte d\'Ivoire': 'CI',
    'Îles Cook': 'CK',
    'Chili': 'CL',
    'Cameroun': 'CM',
    'Chine': 'CN',
    'Colombie': 'CO',
    'Costa Rica': 'CR',
    'Cuba': 'CU',
    'Cap Vert': 'CV',
    'Chypre': 'CY',
    'République tchèque': 'CZ',
    'Tchécoslovaquie': 'CS',
    'Allemagne': 'DE',
    'Allemagne de l\'Ouest': 'DE',
    'Allemagne de l\'Est': 'DE',
    'Djibouti': 'DJ',
    'Danemark': 'DK',
    'Dominique': 'DM',
    'République dominicaine': 'DO',
    'Algérie': 'DZ',
    'Équateur': 'EC',
    'Estonie': 'EE',
    'Egypte': 'EG',
    'Erythree': 'ER',
    'Espagne': 'ES',
    'Ethiopie': 'ET',
    'Finlande': 'FI',
    'Fidji': 'FJ',
    'Îles Malouines': 'FK',
    'Micronesie': 'FM',
    'France': 'FR',
    'Gabon': 'GA',
    'Grande-Bretagne': 'GB',  # modified based on allociné value, originally 'Royaume-Uni'
    'Grenade': 'GD',
    'Géorgie': 'GE',
    'Ghana': 'GH',
    'Gibraltar': 'GI',
    'Gambie': 'GM',
    'Guinée': 'GN',
    'Guinée équatoriale': 'GQ',
    'Grèce': 'GR',
    'Guatemala': 'GT',
    'Guam': 'GU',
    'Guinée-Bissau': 'GW',
    'Guyana': 'GY',
    'Hong Kong': 'HK',
    'Hong-Kong': 'HK',
    'Honduras': 'HN',
    'Croatie': 'HR',
    'Haïti': 'HT',
    'Hongrie': 'HU',
    'Indonésie': 'ID',
    'Irlande': 'IE',
    'Israël': 'IL',
    'Inde': 'IN',
    'Irak': 'IQ',
    'Islande': 'IS',
    'Italie': 'IT',
    'Jamaïque': 'JM',
    'Jordanie': 'JO',
    'Japon': 'JP',
    'Kenya': 'KE',
    'Kyrghyzstan': 'KG',
    'Cambodge': 'KH',
    'Kiribati': 'KI',
    'Comores': 'KM',
    'Saint-Christophe-et-Niévès': 'KN',
    'Corée du Sud': 'KR',  # modified based on allociné value, originally 'Corée, République de'
    'Koweït': 'KW',
    'Îles Caïmans': 'KY',
    'Kazakhstan': 'KZ',
    'Laos': 'LA',
    'Liban': 'LB',
    'Sainte-Lucie': 'LC',
    'Liechtenstein': 'LI',
    'Sri Lanka': 'LK',
    'Libéria': 'LR',
    'Lesotho': 'LS',
    'Lituanie': 'LT',
    'Luxembourg': 'LU',
    'Lettonie': 'LV',
    'Libye': 'LY',
    'Maroc': 'MA',
    'Monaco': 'MC',
    'Moldavie': 'MD',
    'Montenegro': 'ME',
    'Madagascar': 'MG',
    'Îles Marshall': 'MH',
    'Macedoine': 'MK',
    'Mali': 'ML',
    'Birmanie': 'MM',
    'Mongolie': 'MN',
    'Macao': 'MO',
    'Îles Mariannes du nord': 'MP',
    'Mauritanie': 'MR',
    'Montserrat': 'MS',
    'Malte': 'MT',
    'Maurice': 'MU',
    'Maldives': 'MV',
    'Malawi': 'MW',
    'Mexique': 'MX',
    'Malaisie': 'MY',
    'Mozambique': 'MZ',
    'Namibie': 'NA',
    'Niger': 'NE',
    'Nigéria': 'NG',
    'Nicaragua': 'NI',
    'Pays-Bas': 'NL',
    'Norvège': 'NO',
    'Népal': 'NP',
    'Nauru': 'NR',
    'Nioué': 'NU',
    'Nouvelle-Zélande': 'NZ',
    'Oman': 'OM',
    'Panama': 'PA',
    'Pérou': 'PE',
    'Papouasie-Nouvelle-Guinée': 'PG',
    'Philippines': 'PH',
    'Pakistan': 'PK',
    'Pologne': 'PL',
    'Porto Rico': 'PR',
    'Autorité palestinienne': 'PS',
    'Portugal': 'PT',
    'Palaos': 'PW',
    'Paraguay': 'PY',
    'Qatar': 'QA',
    'Roumanie': 'RO',
    'Russie': 'RU',
    'Rwanda': 'RW',
    'Arabie Saoudite': 'SA',
    'Îles Salomon': 'SB',
    'Soudan': 'SD',
    'Suède': 'SE',
    'Singapour': 'SG',
    'Slovénie': 'SI',
    'Slovaquie': 'SK',
    'Sierra Léone': 'SL',
    'Sénégal': 'SN',
    'Somalie': 'SO',
    'Suriname': 'SR',
    'Sao Tomé-et-Principe': 'ST',
    'El Salvador': 'SV',
    'Saint-Martin': 'SX',
    'Syrie': 'SY',
    'Îles Turques-et-Caïques': 'TC',
    'Tchad': 'TD',
    'Togo': 'TG',
    'Thaïlande': 'TH',
    'Tadjikistan': 'TJ',
    'Turkménistan': 'TM',
    'Tunisie': 'TN',
    'Tonga': 'TO',
    'Timor Oriental': 'TP',
    'Turquie': 'TR',
    'Trinité-et-Tobago': 'TT',
    'Tuvalu': 'TV',
    'Taïwan': 'TW',
    'Tanzanie': 'TZ',
    'Ukraine': 'UA',
    'Ouganda': 'UG',
    'U.R.S.S.': 'SU',
    'U.S.A.': 'US',  # modified based on allociné value, originally 'États-unis'
    'Uruguay': 'UY',
    'Ouzbékistan': 'UZ',
    'Saint-Vincent-et-les Grenadines': 'VC',
    'Venezuela': 'VE',
    'Îles Vierges (britanniques)': 'VG',
    'Îles Vierges': 'VI',
    'Viêtnam': 'VN',
    'Vanuatu': 'VU',
    'Samoa occidentales': 'WS',
    'Kosovo': 'XK',
    'Yémen': 'YE',
    'Serbie': 'YU',
    'Afrique du sud': 'ZA',
    'Zambie': 'ZM',
    'Zimbabwe': 'ZW',
}
